 

import java.awt.*;

public class Triangle
{
    private int height;
    private int width;
    private int xPosition;
    private int yPosition;
    private String color;
    private boolean isVisible;

    public Triangle()
    {
        isVisible = false;
        setState(30, 40, 50, 15, "green");
    }
    
   public Triangle(int height, int width, int xPosition, int yPosition, String color)
    { 
        setState(height, width, xPosition, yPosition, color);
    }
    
    public int getHeight()
    {
        return height;
    }
    
    public void setState(int height, int width, int xPosition, int yPosition, String color)
    { 
        this.height = height;
        this.width = width;
        this.xPosition = xPosition;
        this.yPosition = yPosition;
        this.color = color;
    }
    
    public void makeVisible()
    {
        isVisible = true;
        draw();
    }
    
    public void makeInvisible()
    {
        erase();
        isVisible = false;
    }
    
    /**
     * Move the triangle to new position whose coordinates in pixels will be (x, y).
     * @param x the new x coordinate
     * @param y the new y coordinate
     */
    public void moveTo(int x, int y)
    {
        xPosition = x;
        yPosition = y;
        makeVisible();
    }
    
    public void moveRight()
    {
        moveHorizontal(20);
    }

    public void moveLeft()
    {
        moveHorizontal(-20);
    }

 
    public void moveUp()
    {
        moveVertical(-20);
    }

 
    public void moveDown()
    {
        moveVertical(20);
    }

 
    public void moveHorizontal(int distance)
    {
        erase();
        xPosition += distance;
        draw();
    }

 
    public void moveVertical(int distance)
    {
        erase();
        yPosition += distance;
        draw();
    }

    public void slowMoveHorizontal(int distance)
    {
        int delta;

        if(distance < 0) 
        {
            delta = -1;
            distance = -distance;
        }
        else 
        {
            delta = 1;
        }

        for(int i = 0; i < distance; i++)
        {
            xPosition += delta;
            draw();
        }
    }

    public void slowMoveVertical(int distance)
    {
        int delta;

        if(distance < 0) 
        {
            delta = -1;
            distance = -distance;
        }
        else 
        {
            delta = 1;
        }

        for(int i = 0; i < distance; i++)
        {
            yPosition += delta;
            draw();
        }
    }

    public void changeSize(int newHeight, int newWidth)
    {
        erase();
        height = newHeight;
        width = newWidth;
        draw();
    }

    public void changeColor(String newColor)
    {
        color = newColor;
        draw();
    }
    
    private void draw()
    {
        if(isVisible) {
            Canvas canvas = Canvas.getCanvas();
            int[] xpoints = { xPosition, xPosition + (width/2), xPosition - (width/2) };
            int[] ypoints = { yPosition, yPosition + height, yPosition + height };
            canvas.draw(this, color, new Polygon(xpoints, ypoints, 3));
            canvas.wait(10);
        }
    }

    /**
     * Erase the triangle on screen.
     */
    private void erase()
    {
        if(isVisible) {
            Canvas canvas = Canvas.getCanvas();
            canvas.erase(this);
        }
    }
}
